# clu-stress
A non-parametric unsupervised clustering algorithm originally developed for seismic stress inversions.
# Installation
pip install clu-stress==1.2.0\
pypi project: 
https://pypi.org/project/clu-stress/ 
